pub struct ArenaMatchesHistoryRequest {
pub character_id: Uuid,
}Fields
character_id: UuidTrait Implementations
Sourceimpl Clone for ArenaMatchesHistoryRequest
impl Clone for ArenaMatchesHistoryRequest
Sourcefn clone(&self) -> ArenaMatchesHistoryRequest
fn clone(&self) -> ArenaMatchesHistoryRequest
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArenaMatchesHistoryRequest
impl Debug for ArenaMatchesHistoryRequest
Sourceimpl<'de> Deserialize<'de> for ArenaMatchesHistoryRequest
impl<'de> Deserialize<'de> for ArenaMatchesHistoryRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ArenaMatchesHistoryRequest> for JsValuewhere
ArenaMatchesHistoryRequest: Serialize,
impl From<ArenaMatchesHistoryRequest> for JsValuewhere
ArenaMatchesHistoryRequest: Serialize,
Sourcefn from(value: ArenaMatchesHistoryRequest) -> Self
fn from(value: ArenaMatchesHistoryRequest) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for ArenaMatchesHistoryRequestwhere
Self: DeserializeOwned,
impl FromWasmAbi for ArenaMatchesHistoryRequestwhere
Self: DeserializeOwned,
Sourceimpl JsonSchema for ArenaMatchesHistoryRequest
impl JsonSchema for ArenaMatchesHistoryRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for ArenaMatchesHistoryRequestwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for ArenaMatchesHistoryRequestwhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for ArenaMatchesHistoryRequestwhere
ArenaMatchesHistoryRequest: Serialize,
impl OptionIntoWasmAbi for ArenaMatchesHistoryRequestwhere
ArenaMatchesHistoryRequest: Serialize,
Sourceimpl RefFromWasmAbi for ArenaMatchesHistoryRequestwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for ArenaMatchesHistoryRequestwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<ArenaMatchesHistoryRequest>
type Anchor = SelfOwner<ArenaMatchesHistoryRequest>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Tsify for ArenaMatchesHistoryRequest
impl Tsify for ArenaMatchesHistoryRequest
const DECL: &'static str = "export interface ArenaMatchesHistoryRequest {\n character_id: Uuid;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for ArenaMatchesHistoryRequestwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for ArenaMatchesHistoryRequestwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for ArenaMatchesHistoryRequestwhere
ArenaMatchesHistoryRequest: Serialize,
impl VectorIntoWasmAbi for ArenaMatchesHistoryRequestwhere
ArenaMatchesHistoryRequest: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribeVector for ArenaMatchesHistoryRequest
impl WasmDescribeVector for ArenaMatchesHistoryRequest
impl Eq for ArenaMatchesHistoryRequest
impl StructuralPartialEq for ArenaMatchesHistoryRequest