pub struct ArenaPvpPlayersRequest {
pub character_id: Uuid,
}Fields
character_id: UuidTrait Implementations
Sourceimpl Clone for ArenaPvpPlayersRequest
impl Clone for ArenaPvpPlayersRequest
Sourcefn clone(&self) -> ArenaPvpPlayersRequest
fn clone(&self) -> ArenaPvpPlayersRequest
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArenaPvpPlayersRequest
impl Debug for ArenaPvpPlayersRequest
Sourceimpl<'de> Deserialize<'de> for ArenaPvpPlayersRequest
impl<'de> Deserialize<'de> for ArenaPvpPlayersRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ArenaPvpPlayersRequest> for JsValuewhere
ArenaPvpPlayersRequest: Serialize,
impl From<ArenaPvpPlayersRequest> for JsValuewhere
ArenaPvpPlayersRequest: Serialize,
Sourcefn from(value: ArenaPvpPlayersRequest) -> Self
fn from(value: ArenaPvpPlayersRequest) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for ArenaPvpPlayersRequestwhere
Self: DeserializeOwned,
impl FromWasmAbi for ArenaPvpPlayersRequestwhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for ArenaPvpPlayersRequestwhere
ArenaPvpPlayersRequest: Serialize,
impl IntoWasmAbi for ArenaPvpPlayersRequestwhere
ArenaPvpPlayersRequest: Serialize,
Sourceimpl JsonSchema for ArenaPvpPlayersRequest
impl JsonSchema for ArenaPvpPlayersRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for ArenaPvpPlayersRequestwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for ArenaPvpPlayersRequestwhere
Self: DeserializeOwned,
Sourceimpl PartialEq for ArenaPvpPlayersRequest
impl PartialEq for ArenaPvpPlayersRequest
Sourceimpl RefFromWasmAbi for ArenaPvpPlayersRequestwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for ArenaPvpPlayersRequestwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<ArenaPvpPlayersRequest>
type Anchor = SelfOwner<ArenaPvpPlayersRequest>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for ArenaPvpPlayersRequest
impl Serialize for ArenaPvpPlayersRequest
Sourceimpl Tsify for ArenaPvpPlayersRequest
impl Tsify for ArenaPvpPlayersRequest
Sourceimpl VectorFromWasmAbi for ArenaPvpPlayersRequestwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for ArenaPvpPlayersRequestwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for ArenaPvpPlayersRequestwhere
ArenaPvpPlayersRequest: Serialize,
impl VectorIntoWasmAbi for ArenaPvpPlayersRequestwhere
ArenaPvpPlayersRequest: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribeVector for ArenaPvpPlayersRequest
impl WasmDescribeVector for ArenaPvpPlayersRequest
impl Eq for ArenaPvpPlayersRequest
impl StructuralPartialEq for ArenaPvpPlayersRequest