pub struct ArenaStars {
pub arena_stars_daily_claims: i64,
}Fields
arena_stars_daily_claims: i64Trait Implementations
Sourceimpl Clone for ArenaStars
impl Clone for ArenaStars
Sourcefn clone(&self) -> ArenaStars
fn clone(&self) -> ArenaStars
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for ArenaStars
impl CustomType for ArenaStars
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for ArenaStars
impl Debug for ArenaStars
Sourceimpl Default for ArenaStars
impl Default for ArenaStars
Sourcefn default() -> ArenaStars
fn default() -> ArenaStars
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ArenaStars
impl<'de> Deserialize<'de> for ArenaStars
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ArenaStars
impl JsonSchema for ArenaStars
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ArenaStars
impl PartialEq for ArenaStars
Sourceimpl Serialize for ArenaStars
impl Serialize for ArenaStars
Sourceimpl Tsify for ArenaStars
impl Tsify for ArenaStars
const DECL: &'static str = "export interface ArenaStars {\n arena_stars_daily_claims: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for ArenaStars
impl StructuralPartialEq for ArenaStars