pub struct ArenaTickets {
pub current_count: u64,
pub max_count: u64,
pub last_restore_at: DateTime<Utc>,
}Fields
current_count: u64max_count: u64last_restore_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for ArenaTickets
impl Clone for ArenaTickets
Sourcefn clone(&self) -> ArenaTickets
fn clone(&self) -> ArenaTickets
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for ArenaTickets
impl CustomType for ArenaTickets
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for ArenaTickets
impl Debug for ArenaTickets
Sourceimpl Default for ArenaTickets
impl Default for ArenaTickets
Sourcefn default() -> ArenaTickets
fn default() -> ArenaTickets
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ArenaTickets
impl<'de> Deserialize<'de> for ArenaTickets
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ArenaTickets
impl JsonSchema for ArenaTickets
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ArenaTickets
impl PartialEq for ArenaTickets
Sourceimpl Serialize for ArenaTickets
impl Serialize for ArenaTickets
Sourceimpl Tsify for ArenaTickets
impl Tsify for ArenaTickets
const DECL: &'static str = "export interface ArenaTickets {\n current_count: number;\n max_count: number;\n last_restore_at: DateTime<Utc>;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for ArenaTickets
impl StructuralPartialEq for ArenaTickets