pub struct Match {
pub id: ArenaMatchId,
pub opponent: OpponentPreview,
pub is_win: bool,
pub rating_change: i64,
pub duration_secs: u64,
pub is_rematch_available: bool,
pub created_at: DateTime<Utc>,
}Fields
id: ArenaMatchIdopponent: OpponentPreviewis_win: boolrating_change: i64duration_secs: u64is_rematch_available: boolcreated_at: DateTime<Utc>Trait Implementations
Sourceimpl CustomType for Match
impl CustomType for Match
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl<'de> Deserialize<'de> for Match
impl<'de> Deserialize<'de> for Match
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromWasmAbi for Matchwhere
Self: DeserializeOwned,
impl FromWasmAbi for Matchwhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for Match
impl IntoWasmAbi for Match
Sourceimpl JsonSchema for Match
impl JsonSchema for Match
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for Matchwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for Matchwhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for Match
impl OptionIntoWasmAbi for Match
Sourceimpl RefFromWasmAbi for Matchwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for Matchwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourceimpl Tsify for Match
impl Tsify for Match
const DECL: &'static str = "export interface Match {\n id: ArenaMatchId;\n opponent: OpponentPreview;\n is_win: boolean;\n rating_change: number;\n duration_secs: number;\n is_rematch_available: boolean;\n created_at: DateTime<Utc>;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for Matchwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for Matchwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for Match
impl VectorIntoWasmAbi for Match
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
impl Eq for Match
impl StructuralPartialEq for Match