pub struct RankingItem {
pub user: User,
pub character: Character,
pub place: u64,
}Fields
user: Usercharacter: Characterplace: u64Trait Implementations
Sourceimpl Clone for RankingItem
impl Clone for RankingItem
Sourcefn clone(&self) -> RankingItem
fn clone(&self) -> RankingItem
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for RankingItem
impl CustomType for RankingItem
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for RankingItem
impl Debug for RankingItem
Sourceimpl<'de> Deserialize<'de> for RankingItem
impl<'de> Deserialize<'de> for RankingItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RankingItem
impl JsonSchema for RankingItem
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RankingItem
impl PartialEq for RankingItem
Sourceimpl Serialize for RankingItem
impl Serialize for RankingItem
Sourceimpl Tsify for RankingItem
impl Tsify for RankingItem
const DECL: &'static str = "export interface RankingItem {\n user: User;\n character: Character;\n place: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for RankingItem
impl StructuralPartialEq for RankingItem